module DoubleAuthEngine
  module UsersControllerMixin
    def self.included(base)
      base.class_eval do
        skip_before_filter :require_user, :only => [:new, :create]
        filter_access_to [:edit, :update, :change_password, :update_password], :attribute_check => true
        respond_to :html, :json, :js
      end
      base.send :include, InstanceMethods
    end

    module InstanceMethods
      def index
        @users = User.all
        respond_with(@users)
      end

      def show
        @user = User.find(params[:id])
        respond_with @user
      end

      def new
        @user = User.new
        respond_with @user do |format|
          format.html { render :layout => false }
        end
      end

      def create
        @user = User.new(params[:user])
        if @user.save
          flash[:notice] = 'User successfully created'
          respond_with(@user)
        else
          render :action => 'new', :layout => false
        end
      end

      def edit
        @user = User.find(params[:id])
        respond_with(@user)
      end

      def update
        @user = User.find(params[:id])
        if @user.update_attributes(params[:user])
          flash[:notice] = 'User successfully updated'
          respond_with(@user)
        else
          render :action => 'edit'
        end
      end

      def destroy
        @user = User.find(params[:id])
        @user.destroy
        respond_to do |format|
          format.html { redirect_to(users_url) }
          format.xml { head :ok }
        end
      end
      
      def update_password
        @user = User.find(params[:id])
        if @user.valid_password? params[:current_password]
          @user.password              = params[:password]
          @user.password_confirmation = params[:password_confirmation]
          if @user.save
            flash[:notice] = "Your password has been updated"
            redirect_to user_path(@user)
          else
            flash[:error] = @user.errors.full_messages.first
            render :action => "change_password"
          end
        else
          flash[:error] = "Your Current Password Does not Match"
          render :action => "change_password"
        end
      end
    end
  end
end
