require 'rails/generators'

module DoubleAuthEngine
  class InstallGenerator < Rails::Generators::Base
    include Rails::Generators::Migration

    def self.source_root
      @source_root ||= File.join(File.dirname(__FILE__), 'templates')
    end

    def self.next_migration_number(path)
      unless @prev_migration_nr
        @prev_migration_nr = Time.now.utc.strftime("%Y%m%d%H%M%S").to_i
      else
        @prev_migration_nr += 1
      end
      @prev_migration_nr.to_s
    end

    def create_migration_files
      migration_template "user_migration.rb", "db/migrate/create_users.rb"
      migration_template "role_migration.rb", "db/migrate/create_roles.rb"
      migration_template "assignment_migration.rb", "db/migrate/create_assignments.rb"
    end

    def create_initializer_file
      copy_file "setup_mail_initializer.rb", "config/initializers/setup_mail.rb"
    end

    def create_authorization_file
      copy_file "authorization_rules.rb", "config/authorization_rules.rb"
    end

    def update_application_controller
      insert_into_file "app/controllers/application_controller.rb", :after => "class ApplicationController < ActionController::Base\n" do
        "\tinclude DoubleAuthEngine::ApplicationControllerMixin\n"
      end
    end

    # Passing a block to append_to_file would not format nicely,
    # which is why I opted for separate append statements. Don't judge.
    def add_roles
      append_to_file "db/seeds.rb", "if Role.all.empty?\n"
      append_to_file "db/seeds.rb", "\tRole.create(:name => 'admin')\n"
      append_to_file "db/seeds.rb", "end\n"
    end
  end
end
