module DoubleAuthEngine
  module UserMixin
    def self.included(base)
      base.class_eval do
        acts_as_authentic
        validates :email, :name, :presence => true
        validates :name, :length => { :maximum => 100 }
        has_many :assignments
        has_many :roles, :through => :assignments
      end
      base.send :extend, ClassMethods
      base.send :include, InstanceMethods
    end

    module ClassMethods
    end

    module InstanceMethods
      def email=(value)
        write_attribute :email, (value ? value.downcase : nil)
      end

      def deliver_password_reset_instructions!
        reset_perishable_token!
        Notifier.password_reset_instructions(self).deliver
      end

      def role_symbols
        roles.map do |role|
          role.name.underscore.to_sym
        end
      end
    end
  end
end
